@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Common Carla code
-# Copyright (C) 2011-2022 Filipe Coelho <falktx@falktx.com>
+# Copyright (C) 2011-2025 Filipe Coelho <falktx@falktx.com>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -38,7 +38,12 @@ except:
 # ------------------------------------------------------------------------------------------------------------
 # Imports (PyQt5)
 
-from PyQt5.Qt import PYQT_VERSION_STR
+# import changed in PyQt 5.15.8, so try both
+try:
+    from PyQt5.Qt import PYQT_VERSION_STR
+except ImportError:
+    from PyQt5.QtCore import PYQT_VERSION_STR
+
 from PyQt5.QtCore import qFatal, QT_VERSION, QT_VERSION_STR, qWarning, QDir, QSettings
 from PyQt5.QtGui import QIcon
 from PyQt5.QtWidgets import QFileDialog, QMessageBox
@@ -71,7 +76,7 @@ if WINDOWS:
 # ------------------------------------------------------------------------------------------------------------
 # Set Version
 
-VERSION = "2.5.2"
+VERSION = "2.5.10"
 
 # ------------------------------------------------------------------------------------------------------------
 # Set TMP
@@ -296,10 +301,12 @@ CARLA_DEFAULT_AUDIO_BUFFER_SIZE     = 512
 CARLA_DEFAULT_AUDIO_SAMPLE_RATE     = 44100
 CARLA_DEFAULT_AUDIO_TRIPLE_BUFFER   = False
 
-if WINDOWS:
-    CARLA_DEFAULT_AUDIO_DRIVER = "Windows Audio"
+if HAIKU:
+    CARLA_DEFAULT_AUDIO_DRIVER = "SDL"
 elif MACOS:
     CARLA_DEFAULT_AUDIO_DRIVER = "CoreAudio"
+elif WINDOWS:
+    CARLA_DEFAULT_AUDIO_DRIVER = "Windows Audio"
 elif os.path.exists("/usr/bin/jackd") or os.path.exists("/usr/bin/jackdbus") or os.path.exists("/usr/bin/pw-jack"):
     CARLA_DEFAULT_AUDIO_DRIVER = "JACK"
 else:
